/*
 *  nextpnr -- Next Generation Place and Route
 *
 *  Copyright (C) 2018  David Shah <david@symbioticeda.com>
 *
 *  Permission to use, copy, modify, and/or distribute this software for any
 *  purpose with or without fee is hereby granted, provided that the above
 *  copyright notice and this permission notice appear in all copies.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 *  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 *  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 *  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

#ifndef ECP5_GFX_H
#define ECP5_GFX_H

#include "nextpnr.h"

NEXTPNR_NAMESPACE_BEGIN

const float switchbox_x1 = 0.51;
const float switchbox_x2 = 0.90;
const float switchbox_y1 = 0.51;
const float switchbox_y2 = 0.90;

const float slice_x1 = 0.92;
const float slice_x2 = 0.94;
const float slice_y1 = 0.71;
const float slice_y2 = 0.745 + 0.0068;
const float slice_pitch = 0.0374 + 0.0068;

const float io_cell_v_x1 = 0.76;
const float io_cell_v_x2 = 0.95;
const float io_cell_v_y1 = 0.05;
const float io_cell_v_y2 = 0.15;
const float io_cell_v_pitch = 0.125;

const float io_cell_h_x1 = 0.05;
const float io_cell_h_x2 = 0.14;
const float io_cell_h_y1 = 0.05;
const float io_cell_h_y2 = 0.24;
const float io_cell_h_pitch = 0.125;

enum GfxTileWireId
{
    TILE_WIRE_NONE,

    TILE_WIRE_FCO_SLICE,
    TILE_WIRE_D7_SLICE,
    TILE_WIRE_C7_SLICE,
    TILE_WIRE_B7_SLICE,
    TILE_WIRE_A7_SLICE,
    TILE_WIRE_D6_SLICE,
    TILE_WIRE_C6_SLICE,
    TILE_WIRE_B6_SLICE,
    TILE_WIRE_A6_SLICE,
    TILE_WIRE_DI7_SLICE,
    TILE_WIRE_DI6_SLICE,
    TILE_WIRE_M7_SLICE,
    TILE_WIRE_M6_SLICE,
    TILE_WIRE_FXBD_SLICE,
    TILE_WIRE_FXAD_SLICE,
    TILE_WIRE_DUMMY_D1,
    TILE_WIRE_FXD_SLICE,
    TILE_WIRE_F7_SLICE,
    TILE_WIRE_Q7_SLICE,
    TILE_WIRE_Q6_SLICE,
    TILE_WIRE_F6_SLICE,
    TILE_WIRE_F5D_SLICE,
    TILE_WIRE_CE3_SLICE,
    TILE_WIRE_FCID_SLICE,

    TILE_WIRE_FCOC_SLICE,
    TILE_WIRE_D5_SLICE,
    TILE_WIRE_C5_SLICE,
    TILE_WIRE_B5_SLICE,
    TILE_WIRE_A5_SLICE,
    TILE_WIRE_D4_SLICE,
    TILE_WIRE_C4_SLICE,
    TILE_WIRE_B4_SLICE,
    TILE_WIRE_A4_SLICE,
    TILE_WIRE_DI5_SLICE,
    TILE_WIRE_DI4_SLICE,
    TILE_WIRE_M5_SLICE,
    TILE_WIRE_M4_SLICE,
    TILE_WIRE_FXBC_SLICE,
    TILE_WIRE_FXAC_SLICE,
    TILE_WIRE_DUMMY_C1,
    TILE_WIRE_FXC_SLICE,
    TILE_WIRE_F5_SLICE,
    TILE_WIRE_Q5_SLICE,
    TILE_WIRE_Q4_SLICE,
    TILE_WIRE_F4_SLICE,
    TILE_WIRE_F5C_SLICE,
    TILE_WIRE_CE2_SLICE,
    TILE_WIRE_FCIC_SLICE,

    TILE_WIRE_FCOB_SLICE,
    TILE_WIRE_D3_SLICE,
    TILE_WIRE_C3_SLICE,
    TILE_WIRE_B3_SLICE,
    TILE_WIRE_A3_SLICE,
    TILE_WIRE_D2_SLICE,
    TILE_WIRE_C2_SLICE,
    TILE_WIRE_B2_SLICE,
    TILE_WIRE_A2_SLICE,
    TILE_WIRE_DI3_SLICE,
    TILE_WIRE_DI2_SLICE,
    TILE_WIRE_M3_SLICE,
    TILE_WIRE_M2_SLICE,
    TILE_WIRE_FXBB_SLICE,
    TILE_WIRE_FXAB_SLICE,
    TILE_WIRE_DUMMY_B1,
    TILE_WIRE_FXB_SLICE,
    TILE_WIRE_F3_SLICE,
    TILE_WIRE_Q3_SLICE,
    TILE_WIRE_Q2_SLICE,
    TILE_WIRE_F2_SLICE,
    TILE_WIRE_F5B_SLICE,
    TILE_WIRE_CE1_SLICE,
    TILE_WIRE_FCIB_SLICE,

    TILE_WIRE_FCOA_SLICE,
    TILE_WIRE_D1_SLICE,
    TILE_WIRE_C1_SLICE,
    TILE_WIRE_B1_SLICE,
    TILE_WIRE_A1_SLICE,
    TILE_WIRE_D0_SLICE,
    TILE_WIRE_C0_SLICE,
    TILE_WIRE_B0_SLICE,
    TILE_WIRE_A0_SLICE,
    TILE_WIRE_DI1_SLICE,
    TILE_WIRE_DI0_SLICE,
    TILE_WIRE_M1_SLICE,
    TILE_WIRE_M0_SLICE,
    TILE_WIRE_FXBA_SLICE,
    TILE_WIRE_FXAA_SLICE,
    TILE_WIRE_DUMMY_A1,
    TILE_WIRE_FXA_SLICE,
    TILE_WIRE_F1_SLICE,
    TILE_WIRE_Q1_SLICE,
    TILE_WIRE_Q0_SLICE,
    TILE_WIRE_F0_SLICE,
    TILE_WIRE_F5A_SLICE,
    TILE_WIRE_CE0_SLICE,
    TILE_WIRE_FCI_SLICE,

    TILE_WIRE_CLK0,
    TILE_WIRE_CLK1,
    TILE_WIRE_LSR0,
    TILE_WIRE_LSR1,

    TILE_WIRE_FCO,
    TILE_WIRE_D7,
    TILE_WIRE_C7,
    TILE_WIRE_B7,
    TILE_WIRE_A7,
    TILE_WIRE_D6,
    TILE_WIRE_C6,
    TILE_WIRE_B6,
    TILE_WIRE_A6,
    TILE_WIRE_DI7,
    TILE_WIRE_DI6,
    TILE_WIRE_M7,
    TILE_WIRE_M6,
    TILE_WIRE_FXBD,
    TILE_WIRE_FXAD,
    TILE_WIRE_DUMMY_SWB1,
    TILE_WIRE_DUMMY_SWB2,
    TILE_WIRE_F7,
    TILE_WIRE_Q7,
    TILE_WIRE_Q6,
    TILE_WIRE_F6,
    TILE_WIRE_DUMMY_SWB3,
    TILE_WIRE_CE3,
    TILE_WIRE_DUMMY_SWB4,

    TILE_WIRE_DUMMY_SWB5,
    TILE_WIRE_D5,
    TILE_WIRE_C5,
    TILE_WIRE_B5,
    TILE_WIRE_A5,
    TILE_WIRE_D4,
    TILE_WIRE_C4,
    TILE_WIRE_B4,
    TILE_WIRE_A4,
    TILE_WIRE_DI5,
    TILE_WIRE_DI4,
    TILE_WIRE_M5,
    TILE_WIRE_M4,
    TILE_WIRE_FXBC,
    TILE_WIRE_FXAC,
    TILE_WIRE_DUMMY_SWB6,
    TILE_WIRE_DUMMY_SWB7,
    TILE_WIRE_F5,
    TILE_WIRE_Q5,
    TILE_WIRE_Q4,
    TILE_WIRE_F4,
    TILE_WIRE_DUMMY_SWB8,
    TILE_WIRE_CE2,
    TILE_WIRE_DUMMY_SWB9,

    TILE_WIRE_DUMMY_SWB10,
    TILE_WIRE_D3,
    TILE_WIRE_C3,
    TILE_WIRE_B3,
    TILE_WIRE_A3,
    TILE_WIRE_D2,
    TILE_WIRE_C2,
    TILE_WIRE_B2,
    TILE_WIRE_A2,
    TILE_WIRE_DI3,
    TILE_WIRE_DI2,
    TILE_WIRE_M3,
    TILE_WIRE_M2,
    TILE_WIRE_FXBB,
    TILE_WIRE_FXAB,
    TILE_WIRE_DUMMY_SWB11,
    TILE_WIRE_DUMMY_SWB12,
    TILE_WIRE_F3,
    TILE_WIRE_Q3,
    TILE_WIRE_Q2,
    TILE_WIRE_F2,
    TILE_WIRE_DUMMY_SWB13,
    TILE_WIRE_CE1,
    TILE_WIRE_DUMMY_SWB14,

    TILE_WIRE_DUMMY_SWB15,
    TILE_WIRE_D1,
    TILE_WIRE_C1,
    TILE_WIRE_B1,
    TILE_WIRE_A1,
    TILE_WIRE_D0,
    TILE_WIRE_C0,
    TILE_WIRE_B0,
    TILE_WIRE_A0,
    TILE_WIRE_DI1,
    TILE_WIRE_DI0,
    TILE_WIRE_M1,
    TILE_WIRE_M0,
    TILE_WIRE_FXBA,
    TILE_WIRE_FXAA,
    TILE_WIRE_DUMMY_SWB16,
    TILE_WIRE_DUMMY_SWB17,
    TILE_WIRE_F1,
    TILE_WIRE_Q1,
    TILE_WIRE_Q0,
    TILE_WIRE_F0,
    TILE_WIRE_DUMMY_SWB18,
    TILE_WIRE_CE0,
    TILE_WIRE_FCI,

    TILE_WIRE_MUXCLK3,
    TILE_WIRE_MUXLSR3,
    TILE_WIRE_MUXCLK2,
    TILE_WIRE_MUXLSR2,
    TILE_WIRE_MUXCLK1,
    TILE_WIRE_MUXLSR1,
    TILE_WIRE_MUXCLK0,
    TILE_WIRE_MUXLSR0,

    TILE_WIRE_WD3,
    TILE_WIRE_WD2,
    TILE_WIRE_WD1,
    TILE_WIRE_WD0,

    TILE_WIRE_WAD3,
    TILE_WIRE_WAD2,
    TILE_WIRE_WAD1,
    TILE_WIRE_WAD0,

    TILE_WIRE_DUMMY_D2,
    TILE_WIRE_DUMMY_D3,
    TILE_WIRE_CLK3_SLICE,
    TILE_WIRE_LSR3_SLICE,
    TILE_WIRE_DUMMY_D4,
    TILE_WIRE_DUMMY_D5,
    TILE_WIRE_DUMMY_D6,
    TILE_WIRE_DUMMY_D7,
    TILE_WIRE_DUMMY_D8,
    TILE_WIRE_DUMMY_D9,
    TILE_WIRE_DUMMY_D10,
    TILE_WIRE_DUMMY_D11,

    TILE_WIRE_DUMMY_C2,
    TILE_WIRE_DUMMY_C3,
    TILE_WIRE_CLK2_SLICE,
    TILE_WIRE_LSR2_SLICE,
    TILE_WIRE_WDO3C_SLICE,
    TILE_WIRE_WDO2C_SLICE,
    TILE_WIRE_WDO1C_SLICE,
    TILE_WIRE_WDO0C_SLICE,
    TILE_WIRE_WADO3C_SLICE,
    TILE_WIRE_WADO2C_SLICE,
    TILE_WIRE_WADO1C_SLICE,
    TILE_WIRE_WADO0C_SLICE,

    TILE_WIRE_WCK1_SLICE,
    TILE_WIRE_WRE1_SLICE,
    TILE_WIRE_CLK1_SLICE,
    TILE_WIRE_LSR1_SLICE,
    TILE_WIRE_DUMMY_B2,
    TILE_WIRE_DUMMY_B3,
    TILE_WIRE_WD1B_SLICE,
    TILE_WIRE_WD0B_SLICE,
    TILE_WIRE_WAD3B_SLICE,
    TILE_WIRE_WAD2B_SLICE,
    TILE_WIRE_WAD1B_SLICE,
    TILE_WIRE_WAD0B_SLICE,

    TILE_WIRE_WCK0_SLICE,
    TILE_WIRE_WRE0_SLICE,
    TILE_WIRE_CLK0_SLICE,
    TILE_WIRE_LSR0_SLICE,
    TILE_WIRE_DUMMY_A2,
    TILE_WIRE_DUMMY_A3,
    TILE_WIRE_WD1A_SLICE,
    TILE_WIRE_WD0A_SLICE,
    TILE_WIRE_WAD3A_SLICE,
    TILE_WIRE_WAD2A_SLICE,
    TILE_WIRE_WAD1A_SLICE,
    TILE_WIRE_WAD0A_SLICE,

    TILE_WIRE_V01N0001,
    TILE_WIRE_V01N0101,
    TILE_WIRE_V01S0000,
    TILE_WIRE_V01S0100,

    TILE_WIRE_H01E0001,
    TILE_WIRE_H01E0101,
    TILE_WIRE_H01W0000,
    TILE_WIRE_H01W0100,
    TILE_WIRE_HFIE0000,
    TILE_WIRE_HL7W0001,

    TILE_WIRE_V00T0000,
    TILE_WIRE_V00T0100,

    TILE_WIRE_V00B0000,
    TILE_WIRE_V00B0100,

    TILE_WIRE_H00L0000,
    TILE_WIRE_H00L0100,

    TILE_WIRE_H00R0000,
    TILE_WIRE_H00R0100,

    TILE_WIRE_NBOUNCE,
    TILE_WIRE_SBOUNCE,
    TILE_WIRE_WBOUNCE,
    TILE_WIRE_EBOUNCE,

    TILE_WIRE_V02N0701,
    TILE_WIRE_V02S0701,
    TILE_WIRE_V02N0601,
    TILE_WIRE_V02S0601,
    TILE_WIRE_V02N0501,
    TILE_WIRE_V02S0501,
    TILE_WIRE_V02N0401,
    TILE_WIRE_V02S0401,
    TILE_WIRE_V02N0301,
    TILE_WIRE_V02S0301,
    TILE_WIRE_V02N0201,
    TILE_WIRE_V02S0201,
    TILE_WIRE_V02N0101,
    TILE_WIRE_V02S0101,
    TILE_WIRE_V02N0001,
    TILE_WIRE_V02S0001,

    TILE_WIRE_V06N0303,
    TILE_WIRE_V06S0303,
    TILE_WIRE_V06N0203,
    TILE_WIRE_V06S0203,
    TILE_WIRE_V06N0103,
    TILE_WIRE_V06S0103,
    TILE_WIRE_V06N0003,
    TILE_WIRE_V06S0003,

    TILE_WIRE_H02W0701,
    TILE_WIRE_H02E0701,
    TILE_WIRE_H02W0601,
    TILE_WIRE_H02E0601,
    TILE_WIRE_H02W0501,
    TILE_WIRE_H02E0501,
    TILE_WIRE_H02W0401,
    TILE_WIRE_H02E0401,
    TILE_WIRE_H02W0301,
    TILE_WIRE_H02E0301,
    TILE_WIRE_H02W0201,
    TILE_WIRE_H02E0201,
    TILE_WIRE_H02W0101,
    TILE_WIRE_H02E0101,
    TILE_WIRE_H02W0001,
    TILE_WIRE_H02E0001,

    TILE_WIRE_H06W0303,
    TILE_WIRE_H06E0303,
    TILE_WIRE_H06W0203,
    TILE_WIRE_H06E0203,
    TILE_WIRE_H06W0103,
    TILE_WIRE_H06E0103,
    TILE_WIRE_H06W0003,
    TILE_WIRE_H06E0003,

    TILE_WIRE_G_HPBX0000,
    TILE_WIRE_G_HPBX0100,
    TILE_WIRE_G_HPBX0200,
    TILE_WIRE_G_HPBX0300,
    TILE_WIRE_G_HPBX0400,
    TILE_WIRE_G_HPBX0500,
    TILE_WIRE_G_HPBX0600,
    TILE_WIRE_G_HPBX0700,
    TILE_WIRE_G_HPBX0800,
    TILE_WIRE_G_HPBX0900,
    TILE_WIRE_G_HPBX1000,
    TILE_WIRE_G_HPBX1100,
    TILE_WIRE_G_HPBX1200,
    TILE_WIRE_G_HPBX1300,
    TILE_WIRE_G_HPBX1400,
    TILE_WIRE_G_HPBX1500,

    TILE_WIRE_DDRDEL_DQS,
    TILE_WIRE_JRST_DQS,
    TILE_WIRE_ECLK_DQS,
    TILE_WIRE_JDQSR90_DQS,
    TILE_WIRE_JDQSW270_DQS,
    TILE_WIRE_JDQSW_DQS,
    TILE_WIRE_RDPNTR0_DQS,
    TILE_WIRE_RDPNTR1_DQS,
    TILE_WIRE_RDPNTR2_DQS,
    TILE_WIRE_WRPNTR0_DQS,
    TILE_WIRE_WRPNTR1_DQS,
    TILE_WIRE_WRPNTR2_DQS,
    TILE_WIRE_JDQSI_DQS,
    TILE_WIRE_JREAD1_DQS,
    TILE_WIRE_JREAD0_DQS,
    TILE_WIRE_JREADCLKSEL2_DQS,
    TILE_WIRE_JREADCLKSEL1_DQS,
    TILE_WIRE_JREADCLKSEL0_DQS,
    TILE_WIRE_JSCLK_DQS,
    TILE_WIRE_JDYNDELAY0_DQS,
    TILE_WIRE_JDYNDELAY1_DQS,
    TILE_WIRE_JDYNDELAY2_DQS,
    TILE_WIRE_JDYNDELAY3_DQS,
    TILE_WIRE_JDYNDELAY4_DQS,
    TILE_WIRE_JDYNDELAY5_DQS,
    TILE_WIRE_JDYNDELAY6_DQS,
    TILE_WIRE_JDYNDELAY7_DQS,
    TILE_WIRE_JPAUSE_DQS,
    TILE_WIRE_JRDLOADN_DQS,
    TILE_WIRE_JRDMOVE_DQS,
    TILE_WIRE_JRDDIRECTION_DQS,
    TILE_WIRE_JWRLOADN_DQS,
    TILE_WIRE_JWRMOVE_DQS,
    TILE_WIRE_JWRDIRECTION_DQS,
    TILE_WIRE_JDATAVALID_DQS,
    TILE_WIRE_JBURSTDET_DQS,
    TILE_WIRE_JRDCFLAG_DQS,
    TILE_WIRE_JWRCFLAG_DQS,

    TILE_WIRE_JLOADND_IOLOGIC,
    TILE_WIRE_JMOVED_IOLOGIC,
    TILE_WIRE_JDIRECTIOND_IOLOGIC,
    TILE_WIRE_JCFLAGD_IOLOGIC,
    TILE_WIRE_IOLDOD_IOLOGIC,
    TILE_WIRE_IOLTOD_IOLOGIC,
    TILE_WIRE_DID_IOLOGIC,
    TILE_WIRE_IOLDODD_IOLOGIC,
    TILE_WIRE_IOLDOID_IOLOGIC,
    TILE_WIRE_INDDD_IOLOGIC,
    TILE_WIRE_PADDID_IOLOGIC,
    TILE_WIRE_JCLKD_IOLOGIC,
    TILE_WIRE_JCED_IOLOGIC,
    TILE_WIRE_JLSRD_IOLOGIC,
    TILE_WIRE_JTSDATA0D_IOLOGIC,
    TILE_WIRE_JTXDATA0D_IOLOGIC,
    TILE_WIRE_JTXDATA1D_IOLOGIC,
    TILE_WIRE_JRXDATA0D_IOLOGIC,
    TILE_WIRE_JRXDATA1D_IOLOGIC,
    TILE_WIRE_JINFFD_IOLOGIC,
    TILE_WIRE_ECLKD_IOLOGIC,
    TILE_WIRE_JTSDATA1D_IOLOGIC,
    TILE_WIRE_JTXDATA2D_IOLOGIC,
    TILE_WIRE_JTXDATA3D_IOLOGIC,
    TILE_WIRE_JRXDATA2D_IOLOGIC,
    TILE_WIRE_JRXDATA3D_IOLOGIC,
    TILE_WIRE_DQSR90D_IOLOGIC,
    TILE_WIRE_DQSW270D_IOLOGIC,
    TILE_WIRE_DQSWD_IOLOGIC,
    TILE_WIRE_RDPNTR0D_IOLOGIC,
    TILE_WIRE_RDPNTR1D_IOLOGIC,
    TILE_WIRE_RDPNTR2D_IOLOGIC,
    TILE_WIRE_WRPNTR0D_IOLOGIC,
    TILE_WIRE_WRPNTR1D_IOLOGIC,
    TILE_WIRE_WRPNTR2D_IOLOGIC,
    TILE_WIRE_DUMMYD1_IOLOGIC,
    TILE_WIRE_DUMMYD2_IOLOGIC,
    TILE_WIRE_DUMMYD3_IOLOGIC,
    TILE_WIRE_DUMMYD4_IOLOGIC,
    TILE_WIRE_DUMMYD5_IOLOGIC,
    TILE_WIRE_DUMMYD6_IOLOGIC,
    TILE_WIRE_DUMMYD7_IOLOGIC,

    TILE_WIRE_JLOADNC_IOLOGIC,
    TILE_WIRE_JMOVEC_IOLOGIC,
    TILE_WIRE_JDIRECTIONC_IOLOGIC,
    TILE_WIRE_JCFLAGC_IOLOGIC,
    TILE_WIRE_IOLDOC_IOLOGIC,
    TILE_WIRE_IOLTOC_IOLOGIC,
    TILE_WIRE_DIC_IOLOGIC,
    TILE_WIRE_IOLDODC_IOLOGIC,
    TILE_WIRE_IOLDOIC_IOLOGIC,
    TILE_WIRE_INDDC_IOLOGIC,
    TILE_WIRE_PADDIC_IOLOGIC,
    TILE_WIRE_JCLKC_IOLOGIC,
    TILE_WIRE_JCEC_IOLOGIC,
    TILE_WIRE_JLSRC_IOLOGIC,
    TILE_WIRE_JTSDATA0C_IOLOGIC,
    TILE_WIRE_JTXDATA0C_IOLOGIC,
    TILE_WIRE_JTXDATA1C_IOLOGIC,
    TILE_WIRE_JRXDATA0C_IOLOGIC,
    TILE_WIRE_JRXDATA1C_IOLOGIC,
    TILE_WIRE_JINFFC_IOLOGIC,
    TILE_WIRE_ECLKC_IOLOGIC,
    TILE_WIRE_JTSDATA1C_IOLOGIC,
    TILE_WIRE_JTXDATA2C_IOLOGIC,
    TILE_WIRE_JTXDATA3C_IOLOGIC,
    TILE_WIRE_JRXDATA2C_IOLOGIC,
    TILE_WIRE_JRXDATA3C_IOLOGIC,
    TILE_WIRE_JTXDATA4C_IOLOGIC,
    TILE_WIRE_JTXDATA5C_IOLOGIC,
    TILE_WIRE_JTXDATA6C_IOLOGIC,
    TILE_WIRE_JSLIPC_IOLOGIC,
    TILE_WIRE_JRXDATA4C_IOLOGIC,
    TILE_WIRE_JRXDATA5C_IOLOGIC,
    TILE_WIRE_JRXDATA6C_IOLOGIC,
    TILE_WIRE_DQSR90C_IOLOGIC,
    TILE_WIRE_DQSW270C_IOLOGIC,
    TILE_WIRE_DQSWC_IOLOGIC,
    TILE_WIRE_RDPNTR0C_IOLOGIC,
    TILE_WIRE_RDPNTR1C_IOLOGIC,
    TILE_WIRE_RDPNTR2C_IOLOGIC,
    TILE_WIRE_WRPNTR0C_IOLOGIC,
    TILE_WIRE_WRPNTR1C_IOLOGIC,
    TILE_WIRE_WRPNTR2C_IOLOGIC,

    TILE_WIRE_JLOADNB_IOLOGIC,
    TILE_WIRE_JMOVEB_IOLOGIC,
    TILE_WIRE_JDIRECTIONB_IOLOGIC,
    TILE_WIRE_JCFLAGB_IOLOGIC,
    TILE_WIRE_IOLDOB_IOLOGIC,
    TILE_WIRE_IOLTOB_IOLOGIC,
    TILE_WIRE_DIB_IOLOGIC,
    TILE_WIRE_IOLDODB_IOLOGIC,
    TILE_WIRE_IOLDOIB_IOLOGIC,
    TILE_WIRE_INDDB_IOLOGIC,
    TILE_WIRE_PADDIB_IOLOGIC,
    TILE_WIRE_JCLKB_IOLOGIC,
    TILE_WIRE_JCEB_IOLOGIC,
    TILE_WIRE_JLSRB_IOLOGIC,
    TILE_WIRE_JTSDATA0B_IOLOGIC,
    TILE_WIRE_JTXDATA0B_IOLOGIC,
    TILE_WIRE_JTXDATA1B_IOLOGIC,
    TILE_WIRE_JRXDATA0B_IOLOGIC,
    TILE_WIRE_JRXDATA1B_IOLOGIC,
    TILE_WIRE_JINFFB_IOLOGIC,
    TILE_WIRE_ECLKB_IOLOGIC,
    TILE_WIRE_JTSDATA1B_IOLOGIC,
    TILE_WIRE_JTXDATA2B_IOLOGIC,
    TILE_WIRE_JTXDATA3B_IOLOGIC,
    TILE_WIRE_JRXDATA2B_IOLOGIC,
    TILE_WIRE_JRXDATA3B_IOLOGIC,
    TILE_WIRE_DQSR90B_IOLOGIC,
    TILE_WIRE_DQSW270B_IOLOGIC,
    TILE_WIRE_DQSWB_IOLOGIC,
    TILE_WIRE_RDPNTR0B_IOLOGIC,
    TILE_WIRE_RDPNTR1B_IOLOGIC,
    TILE_WIRE_RDPNTR2B_IOLOGIC,
    TILE_WIRE_WRPNTR0B_IOLOGIC,
    TILE_WIRE_WRPNTR1B_IOLOGIC,
    TILE_WIRE_WRPNTR2B_IOLOGIC,
    TILE_WIRE_DUMMYB1_IOLOGIC,
    TILE_WIRE_DUMMYB2_IOLOGIC,
    TILE_WIRE_DUMMYB3_IOLOGIC,
    TILE_WIRE_DUMMYB4_IOLOGIC,
    TILE_WIRE_DUMMYB5_IOLOGIC,
    TILE_WIRE_DUMMYB6_IOLOGIC,
    TILE_WIRE_DUMMYB7_IOLOGIC,

    TILE_WIRE_JLOADNA_IOLOGIC,
    TILE_WIRE_JMOVEA_IOLOGIC,
    TILE_WIRE_JDIRECTIONA_IOLOGIC,
    TILE_WIRE_JCFLAGA_IOLOGIC,
    TILE_WIRE_IOLDOA_IOLOGIC,
    TILE_WIRE_IOLTOA_IOLOGIC,
    TILE_WIRE_DIA_IOLOGIC,
    TILE_WIRE_IOLDODA_IOLOGIC,
    TILE_WIRE_IOLDOIA_IOLOGIC,
    TILE_WIRE_INDDA_IOLOGIC,
    TILE_WIRE_PADDIA_IOLOGIC,
    TILE_WIRE_JCLKA_IOLOGIC,
    TILE_WIRE_JCEA_IOLOGIC,
    TILE_WIRE_JLSRA_IOLOGIC,
    TILE_WIRE_JTSDATA0A_IOLOGIC,
    TILE_WIRE_JTXDATA0A_IOLOGIC,
    TILE_WIRE_JTXDATA1A_IOLOGIC,
    TILE_WIRE_JRXDATA0A_IOLOGIC,
    TILE_WIRE_JRXDATA1A_IOLOGIC,
    TILE_WIRE_JINFFA_IOLOGIC,
    TILE_WIRE_ECLKA_IOLOGIC,
    TILE_WIRE_JTSDATA1A_IOLOGIC,
    TILE_WIRE_JTXDATA2A_IOLOGIC,
    TILE_WIRE_JTXDATA3A_IOLOGIC,
    TILE_WIRE_JRXDATA2A_IOLOGIC,
    TILE_WIRE_JRXDATA3A_IOLOGIC,
    TILE_WIRE_JTXDATA4A_IOLOGIC,
    TILE_WIRE_JTXDATA5A_IOLOGIC,
    TILE_WIRE_JTXDATA6A_IOLOGIC,
    TILE_WIRE_JSLIPA_IOLOGIC,
    TILE_WIRE_JRXDATA4A_IOLOGIC,
    TILE_WIRE_JRXDATA5A_IOLOGIC,
    TILE_WIRE_JRXDATA6A_IOLOGIC,
    TILE_WIRE_DQSR90A_IOLOGIC,
    TILE_WIRE_DQSW270A_IOLOGIC,
    TILE_WIRE_DQSWA_IOLOGIC,
    TILE_WIRE_RDPNTR0A_IOLOGIC,
    TILE_WIRE_RDPNTR1A_IOLOGIC,
    TILE_WIRE_RDPNTR2A_IOLOGIC,
    TILE_WIRE_WRPNTR0A_IOLOGIC,
    TILE_WIRE_WRPNTR1A_IOLOGIC,
    TILE_WIRE_WRPNTR2A_IOLOGIC,

    TILE_WIRE_PADDOD_PIO,
    TILE_WIRE_PADDTD_PIO,
    TILE_WIRE_JPADDID_PIO,
    TILE_WIRE_IOLDOD_PIO,
    TILE_WIRE_IOLTOD_PIO,
    TILE_WIRE_PADDOC_PIO,
    TILE_WIRE_PADDTC_PIO,
    TILE_WIRE_JPADDIC_PIO,
    TILE_WIRE_IOLDOC_PIO,
    TILE_WIRE_IOLTOC_PIO,
    TILE_WIRE_PADDOB_PIO,
    TILE_WIRE_PADDTB_PIO,
    TILE_WIRE_JPADDIB_PIO,
    TILE_WIRE_IOLDOB_PIO,
    TILE_WIRE_IOLTOB_PIO,
    TILE_WIRE_PADDOA_PIO,
    TILE_WIRE_PADDTA_PIO,
    TILE_WIRE_JPADDIA_PIO,
    TILE_WIRE_IOLDOA_PIO,
    TILE_WIRE_IOLTOA_PIO,

    TILE_WIRE_DDRDEL_DDRDLL,
    TILE_WIRE_JRST_DDRDLL,
    TILE_WIRE_JCLK_DDRDLL,
    TILE_WIRE_JUDDCNTLN_DDRDLL,
    TILE_WIRE_JFREEZE_DDRDLL,
    TILE_WIRE_JLOCK_DDRDLL,
    TILE_WIRE_JDIVOSC_DDRDLL,
    TILE_WIRE_JDCNTL0_DDRDLL,
    TILE_WIRE_JDCNTL1_DDRDLL,
    TILE_WIRE_JDCNTL2_DDRDLL,
    TILE_WIRE_JDCNTL3_DDRDLL,
    TILE_WIRE_JDCNTL4_DDRDLL,
    TILE_WIRE_JDCNTL5_DDRDLL,
    TILE_WIRE_JDCNTL6_DDRDLL,
    TILE_WIRE_JDCNTL7_DDRDLL,

    TILE_WIRE_JADA0_EBR,
    TILE_WIRE_JADB0_EBR,
    TILE_WIRE_JADA1_EBR,
    TILE_WIRE_JADB1_EBR,
    TILE_WIRE_JADA2_EBR,
    TILE_WIRE_JADB2_EBR,
    TILE_WIRE_JADA3_EBR,
    TILE_WIRE_JADB3_EBR,
    TILE_WIRE_JADA4_EBR,
    TILE_WIRE_JADB4_EBR,
    TILE_WIRE_JADA5_EBR,
    TILE_WIRE_JADB5_EBR,
    TILE_WIRE_JADA6_EBR,
    TILE_WIRE_JADB6_EBR,
    TILE_WIRE_JADA7_EBR,
    TILE_WIRE_JADB7_EBR,
    TILE_WIRE_JADA8_EBR,
    TILE_WIRE_JADB8_EBR,
    TILE_WIRE_JADA9_EBR,
    TILE_WIRE_JADB9_EBR,
    TILE_WIRE_JADA10_EBR,
    TILE_WIRE_JADB10_EBR,
    TILE_WIRE_JADA11_EBR,
    TILE_WIRE_JADB11_EBR,
    TILE_WIRE_JADA12_EBR,
    TILE_WIRE_JADB12_EBR,
    TILE_WIRE_JADA13_EBR,
    TILE_WIRE_JADB13_EBR,
    TILE_WIRE_JCEA_EBR,
    TILE_WIRE_JCEB_EBR,
    TILE_WIRE_JCLKA_EBR,
    TILE_WIRE_JCLKB_EBR,
    TILE_WIRE_JCSA0_EBR,
    TILE_WIRE_JCSA1_EBR,
    TILE_WIRE_JCSA2_EBR,
    TILE_WIRE_JCSB0_EBR,
    TILE_WIRE_JCSB1_EBR,
    TILE_WIRE_JCSB2_EBR,
    TILE_WIRE_JDIA0_EBR,
    TILE_WIRE_JDIB0_EBR,
    TILE_WIRE_JDOA0_EBR,
    TILE_WIRE_JDOB0_EBR,
    TILE_WIRE_JDIA1_EBR,
    TILE_WIRE_JDIB1_EBR,
    TILE_WIRE_JDOA1_EBR,
    TILE_WIRE_JDOB1_EBR,
    TILE_WIRE_JDIA2_EBR,
    TILE_WIRE_JDIB2_EBR,
    TILE_WIRE_JDOA2_EBR,
    TILE_WIRE_JDOB2_EBR,
    TILE_WIRE_JDIA3_EBR,
    TILE_WIRE_JDIB3_EBR,
    TILE_WIRE_JDOA3_EBR,
    TILE_WIRE_JDOB3_EBR,
    TILE_WIRE_JDIA4_EBR,
    TILE_WIRE_JDIB4_EBR,
    TILE_WIRE_JDOA4_EBR,
    TILE_WIRE_JDOB4_EBR,
    TILE_WIRE_JDIA5_EBR,
    TILE_WIRE_JDIB5_EBR,
    TILE_WIRE_JDOA5_EBR,
    TILE_WIRE_JDOB5_EBR,
    TILE_WIRE_JDIA6_EBR,
    TILE_WIRE_JDIB6_EBR,
    TILE_WIRE_JDOA6_EBR,
    TILE_WIRE_JDOB6_EBR,
    TILE_WIRE_JDIA7_EBR,
    TILE_WIRE_JDIB7_EBR,
    TILE_WIRE_JDOA7_EBR,
    TILE_WIRE_JDOB7_EBR,
    TILE_WIRE_JDIA8_EBR,
    TILE_WIRE_JDIB8_EBR,
    TILE_WIRE_JDOA8_EBR,
    TILE_WIRE_JDOB8_EBR,
    TILE_WIRE_JDIA9_EBR,
    TILE_WIRE_JDIB9_EBR,
    TILE_WIRE_JDOA9_EBR,
    TILE_WIRE_JDOB9_EBR,
    TILE_WIRE_JDIA10_EBR,
    TILE_WIRE_JDIB10_EBR,
    TILE_WIRE_JDOA10_EBR,
    TILE_WIRE_JDOB10_EBR,
    TILE_WIRE_JDIA11_EBR,
    TILE_WIRE_JDIB11_EBR,
    TILE_WIRE_JDOA11_EBR,
    TILE_WIRE_JDOB11_EBR,
    TILE_WIRE_JDIA12_EBR,
    TILE_WIRE_JDIB12_EBR,
    TILE_WIRE_JDOA12_EBR,
    TILE_WIRE_JDOB12_EBR,
    TILE_WIRE_JDIA13_EBR,
    TILE_WIRE_JDIB13_EBR,
    TILE_WIRE_JDOA13_EBR,
    TILE_WIRE_JDOB13_EBR,
    TILE_WIRE_JDIA14_EBR,
    TILE_WIRE_JDIB14_EBR,
    TILE_WIRE_JDOA14_EBR,
    TILE_WIRE_JDOB14_EBR,
    TILE_WIRE_JDIA15_EBR,
    TILE_WIRE_JDIB15_EBR,
    TILE_WIRE_JDOA15_EBR,
    TILE_WIRE_JDOB15_EBR,
    TILE_WIRE_JDIA16_EBR,
    TILE_WIRE_JDIB16_EBR,
    TILE_WIRE_JDOA16_EBR,
    TILE_WIRE_JDOB16_EBR,
    TILE_WIRE_JDIA17_EBR,
    TILE_WIRE_JDIB17_EBR,
    TILE_WIRE_JDOA17_EBR,
    TILE_WIRE_JDOB17_EBR,
    TILE_WIRE_JOCEA_EBR,
    TILE_WIRE_JOCEB_EBR,
    TILE_WIRE_JRSTA_EBR,
    TILE_WIRE_JRSTB_EBR,
    TILE_WIRE_JWEA_EBR,
    TILE_WIRE_JWEB_EBR,

    TILE_WIRE_JCLK0_MULT18,
    TILE_WIRE_JCLK1_MULT18,
    TILE_WIRE_JCLK2_MULT18,
    TILE_WIRE_JCLK3_MULT18,
    TILE_WIRE_JCE0_MULT18,
    TILE_WIRE_JCE1_MULT18,
    TILE_WIRE_JCE2_MULT18,
    TILE_WIRE_JCE3_MULT18,
    TILE_WIRE_JRST0_MULT18,
    TILE_WIRE_JRST1_MULT18,
    TILE_WIRE_JRST2_MULT18,
    TILE_WIRE_JRST3_MULT18,
    TILE_WIRE_JA0_MULT18,
    TILE_WIRE_JA1_MULT18,
    TILE_WIRE_JA2_MULT18,
    TILE_WIRE_JA3_MULT18,
    TILE_WIRE_JA4_MULT18,
    TILE_WIRE_JA5_MULT18,
    TILE_WIRE_JA6_MULT18,
    TILE_WIRE_JA7_MULT18,
    TILE_WIRE_JA8_MULT18,
    TILE_WIRE_JA9_MULT18,
    TILE_WIRE_JA10_MULT18,
    TILE_WIRE_JA11_MULT18,
    TILE_WIRE_JA12_MULT18,
    TILE_WIRE_JA13_MULT18,
    TILE_WIRE_JA14_MULT18,
    TILE_WIRE_JA15_MULT18,
    TILE_WIRE_JA16_MULT18,
    TILE_WIRE_JA17_MULT18,
    TILE_WIRE_JB0_MULT18,
    TILE_WIRE_JB1_MULT18,
    TILE_WIRE_JB2_MULT18,
    TILE_WIRE_JB3_MULT18,
    TILE_WIRE_JB4_MULT18,
    TILE_WIRE_JB5_MULT18,
    TILE_WIRE_JB6_MULT18,
    TILE_WIRE_JB7_MULT18,
    TILE_WIRE_JB8_MULT18,
    TILE_WIRE_JB9_MULT18,
    TILE_WIRE_JB10_MULT18,
    TILE_WIRE_JB11_MULT18,
    TILE_WIRE_JB12_MULT18,
    TILE_WIRE_JB13_MULT18,
    TILE_WIRE_JB14_MULT18,
    TILE_WIRE_JB15_MULT18,
    TILE_WIRE_JB16_MULT18,
    TILE_WIRE_JB17_MULT18,
    TILE_WIRE_JC0_MULT18,
    TILE_WIRE_JC1_MULT18,
    TILE_WIRE_JC2_MULT18,
    TILE_WIRE_JC3_MULT18,
    TILE_WIRE_JC4_MULT18,
    TILE_WIRE_JC5_MULT18,
    TILE_WIRE_JC6_MULT18,
    TILE_WIRE_JC7_MULT18,
    TILE_WIRE_JC8_MULT18,
    TILE_WIRE_JC9_MULT18,
    TILE_WIRE_JC10_MULT18,
    TILE_WIRE_JC11_MULT18,
    TILE_WIRE_JC12_MULT18,
    TILE_WIRE_JC13_MULT18,
    TILE_WIRE_JC14_MULT18,
    TILE_WIRE_JC15_MULT18,
    TILE_WIRE_JC16_MULT18,
    TILE_WIRE_JC17_MULT18,
    TILE_WIRE_JSIGNEDA_MULT18,
    TILE_WIRE_JSIGNEDB_MULT18,
    TILE_WIRE_JSOURCEA_MULT18,
    TILE_WIRE_JSOURCEB_MULT18,
    TILE_WIRE_JSRIA0_MULT18,
    TILE_WIRE_JSRIA1_MULT18,
    TILE_WIRE_JSRIA2_MULT18,
    TILE_WIRE_JSRIA3_MULT18,
    TILE_WIRE_JSRIA4_MULT18,
    TILE_WIRE_JSRIA5_MULT18,
    TILE_WIRE_JSRIA6_MULT18,
    TILE_WIRE_JSRIA7_MULT18,
    TILE_WIRE_JSRIA8_MULT18,
    TILE_WIRE_JSRIA9_MULT18,
    TILE_WIRE_JSRIA10_MULT18,
    TILE_WIRE_JSRIA11_MULT18,
    TILE_WIRE_JSRIA12_MULT18,
    TILE_WIRE_JSRIA13_MULT18,
    TILE_WIRE_JSRIA14_MULT18,
    TILE_WIRE_JSRIA15_MULT18,
    TILE_WIRE_JSRIA16_MULT18,
    TILE_WIRE_JSRIA17_MULT18,
    TILE_WIRE_JSRIB0_MULT18,
    TILE_WIRE_JSRIB1_MULT18,
    TILE_WIRE_JSRIB2_MULT18,
    TILE_WIRE_JSRIB3_MULT18,
    TILE_WIRE_JSRIB4_MULT18,
    TILE_WIRE_JSRIB5_MULT18,
    TILE_WIRE_JSRIB6_MULT18,
    TILE_WIRE_JSRIB7_MULT18,
    TILE_WIRE_JSRIB8_MULT18,
    TILE_WIRE_JSRIB9_MULT18,
    TILE_WIRE_JSRIB10_MULT18,
    TILE_WIRE_JSRIB11_MULT18,
    TILE_WIRE_JSRIB12_MULT18,
    TILE_WIRE_JSRIB13_MULT18,
    TILE_WIRE_JSRIB14_MULT18,
    TILE_WIRE_JSRIB15_MULT18,
    TILE_WIRE_JSRIB16_MULT18,
    TILE_WIRE_JSRIB17_MULT18,
    TILE_WIRE_JROA0_MULT18,
    TILE_WIRE_JROA1_MULT18,
    TILE_WIRE_JROA2_MULT18,
    TILE_WIRE_JROA3_MULT18,
    TILE_WIRE_JROA4_MULT18,
    TILE_WIRE_JROA5_MULT18,
    TILE_WIRE_JROA6_MULT18,
    TILE_WIRE_JROA7_MULT18,
    TILE_WIRE_JROA8_MULT18,
    TILE_WIRE_JROA9_MULT18,
    TILE_WIRE_JROA10_MULT18,
    TILE_WIRE_JROA11_MULT18,
    TILE_WIRE_JROA12_MULT18,
    TILE_WIRE_JROA13_MULT18,
    TILE_WIRE_JROA14_MULT18,
    TILE_WIRE_JROA15_MULT18,
    TILE_WIRE_JROA16_MULT18,
    TILE_WIRE_JROA17_MULT18,
    TILE_WIRE_JROB0_MULT18,
    TILE_WIRE_JROB1_MULT18,
    TILE_WIRE_JROB2_MULT18,
    TILE_WIRE_JROB3_MULT18,
    TILE_WIRE_JROB4_MULT18,
    TILE_WIRE_JROB5_MULT18,
    TILE_WIRE_JROB6_MULT18,
    TILE_WIRE_JROB7_MULT18,
    TILE_WIRE_JROB8_MULT18,
    TILE_WIRE_JROB9_MULT18,
    TILE_WIRE_JROB10_MULT18,
    TILE_WIRE_JROB11_MULT18,
    TILE_WIRE_JROB12_MULT18,
    TILE_WIRE_JROB13_MULT18,
    TILE_WIRE_JROB14_MULT18,
    TILE_WIRE_JROB15_MULT18,
    TILE_WIRE_JROB16_MULT18,
    TILE_WIRE_JROB17_MULT18,
    TILE_WIRE_JROC0_MULT18,
    TILE_WIRE_JROC1_MULT18,
    TILE_WIRE_JROC2_MULT18,
    TILE_WIRE_JROC3_MULT18,
    TILE_WIRE_JROC4_MULT18,
    TILE_WIRE_JROC5_MULT18,
    TILE_WIRE_JROC6_MULT18,
    TILE_WIRE_JROC7_MULT18,
    TILE_WIRE_JROC8_MULT18,
    TILE_WIRE_JROC9_MULT18,
    TILE_WIRE_JROC10_MULT18,
    TILE_WIRE_JROC11_MULT18,
    TILE_WIRE_JROC12_MULT18,
    TILE_WIRE_JROC13_MULT18,
    TILE_WIRE_JROC14_MULT18,
    TILE_WIRE_JROC15_MULT18,
    TILE_WIRE_JROC16_MULT18,
    TILE_WIRE_JROC17_MULT18,
    TILE_WIRE_JSROA0_MULT18,
    TILE_WIRE_JSROA1_MULT18,
    TILE_WIRE_JSROA2_MULT18,
    TILE_WIRE_JSROA3_MULT18,
    TILE_WIRE_JSROA4_MULT18,
    TILE_WIRE_JSROA5_MULT18,
    TILE_WIRE_JSROA6_MULT18,
    TILE_WIRE_JSROA7_MULT18,
    TILE_WIRE_JSROA8_MULT18,
    TILE_WIRE_JSROA9_MULT18,
    TILE_WIRE_JSROA10_MULT18,
    TILE_WIRE_JSROA11_MULT18,
    TILE_WIRE_JSROA12_MULT18,
    TILE_WIRE_JSROA13_MULT18,
    TILE_WIRE_JSROA14_MULT18,
    TILE_WIRE_JSROA15_MULT18,
    TILE_WIRE_JSROA16_MULT18,
    TILE_WIRE_JSROA17_MULT18,
    TILE_WIRE_JSROB0_MULT18,
    TILE_WIRE_JSROB1_MULT18,
    TILE_WIRE_JSROB2_MULT18,
    TILE_WIRE_JSROB3_MULT18,
    TILE_WIRE_JSROB4_MULT18,
    TILE_WIRE_JSROB5_MULT18,
    TILE_WIRE_JSROB6_MULT18,
    TILE_WIRE_JSROB7_MULT18,
    TILE_WIRE_JSROB8_MULT18,
    TILE_WIRE_JSROB9_MULT18,
    TILE_WIRE_JSROB10_MULT18,
    TILE_WIRE_JSROB11_MULT18,
    TILE_WIRE_JSROB12_MULT18,
    TILE_WIRE_JSROB13_MULT18,
    TILE_WIRE_JSROB14_MULT18,
    TILE_WIRE_JSROB15_MULT18,
    TILE_WIRE_JSROB16_MULT18,
    TILE_WIRE_JSROB17_MULT18,
    TILE_WIRE_JP0_MULT18,
    TILE_WIRE_JP1_MULT18,
    TILE_WIRE_JP2_MULT18,
    TILE_WIRE_JP3_MULT18,
    TILE_WIRE_JP4_MULT18,
    TILE_WIRE_JP5_MULT18,
    TILE_WIRE_JP6_MULT18,
    TILE_WIRE_JP7_MULT18,
    TILE_WIRE_JP8_MULT18,
    TILE_WIRE_JP9_MULT18,
    TILE_WIRE_JP10_MULT18,
    TILE_WIRE_JP11_MULT18,
    TILE_WIRE_JP12_MULT18,
    TILE_WIRE_JP13_MULT18,
    TILE_WIRE_JP14_MULT18,
    TILE_WIRE_JP15_MULT18,
    TILE_WIRE_JP16_MULT18,
    TILE_WIRE_JP17_MULT18,
    TILE_WIRE_JP18_MULT18,
    TILE_WIRE_JP19_MULT18,
    TILE_WIRE_JP20_MULT18,
    TILE_WIRE_JP21_MULT18,
    TILE_WIRE_JP22_MULT18,
    TILE_WIRE_JP23_MULT18,
    TILE_WIRE_JP24_MULT18,
    TILE_WIRE_JP25_MULT18,
    TILE_WIRE_JP26_MULT18,
    TILE_WIRE_JP27_MULT18,
    TILE_WIRE_JP28_MULT18,
    TILE_WIRE_JP29_MULT18,
    TILE_WIRE_JP30_MULT18,
    TILE_WIRE_JP31_MULT18,
    TILE_WIRE_JP32_MULT18,
    TILE_WIRE_JP33_MULT18,
    TILE_WIRE_JP34_MULT18,
    TILE_WIRE_JP35_MULT18,
    TILE_WIRE_JSIGNEDP_MULT18,

    TILE_WIRE_JCLK0_ALU54,
    TILE_WIRE_JCLK1_ALU54,
    TILE_WIRE_JCLK2_ALU54,
    TILE_WIRE_JCLK3_ALU54,
    TILE_WIRE_JCE0_ALU54,
    TILE_WIRE_JCE1_ALU54,
    TILE_WIRE_JCE2_ALU54,
    TILE_WIRE_JCE3_ALU54,
    TILE_WIRE_JRST0_ALU54,
    TILE_WIRE_JRST1_ALU54,
    TILE_WIRE_JRST2_ALU54,
    TILE_WIRE_JRST3_ALU54,
    TILE_WIRE_JSIGNEDIA_ALU54,
    TILE_WIRE_JSIGNEDIB_ALU54,
    TILE_WIRE_JSIGNEDCIN_ALU54,
    TILE_WIRE_JA0_ALU54,
    TILE_WIRE_JA1_ALU54,
    TILE_WIRE_JA2_ALU54,
    TILE_WIRE_JA3_ALU54,
    TILE_WIRE_JA4_ALU54,
    TILE_WIRE_JA5_ALU54,
    TILE_WIRE_JA6_ALU54,
    TILE_WIRE_JA7_ALU54,
    TILE_WIRE_JA8_ALU54,
    TILE_WIRE_JA9_ALU54,
    TILE_WIRE_JA10_ALU54,
    TILE_WIRE_JA11_ALU54,
    TILE_WIRE_JA12_ALU54,
    TILE_WIRE_JA13_ALU54,
    TILE_WIRE_JA14_ALU54,
    TILE_WIRE_JA15_ALU54,
    TILE_WIRE_JA16_ALU54,
    TILE_WIRE_JA17_ALU54,
    TILE_WIRE_JA18_ALU54,
    TILE_WIRE_JA19_ALU54,
    TILE_WIRE_JA20_ALU54,
    TILE_WIRE_JA21_ALU54,
    TILE_WIRE_JA22_ALU54,
    TILE_WIRE_JA23_ALU54,
    TILE_WIRE_JA24_ALU54,
    TILE_WIRE_JA25_ALU54,
    TILE_WIRE_JA26_ALU54,
    TILE_WIRE_JA27_ALU54,
    TILE_WIRE_JA28_ALU54,
    TILE_WIRE_JA29_ALU54,
    TILE_WIRE_JA30_ALU54,
    TILE_WIRE_JA31_ALU54,
    TILE_WIRE_JA32_ALU54,
    TILE_WIRE_JA33_ALU54,
    TILE_WIRE_JA34_ALU54,
    TILE_WIRE_JA35_ALU54,
    TILE_WIRE_JB0_ALU54,
    TILE_WIRE_JB1_ALU54,
    TILE_WIRE_JB2_ALU54,
    TILE_WIRE_JB3_ALU54,
    TILE_WIRE_JB4_ALU54,
    TILE_WIRE_JB5_ALU54,
    TILE_WIRE_JB6_ALU54,
    TILE_WIRE_JB7_ALU54,
    TILE_WIRE_JB8_ALU54,
    TILE_WIRE_JB9_ALU54,
    TILE_WIRE_JB10_ALU54,
    TILE_WIRE_JB11_ALU54,
    TILE_WIRE_JB12_ALU54,
    TILE_WIRE_JB13_ALU54,
    TILE_WIRE_JB14_ALU54,
    TILE_WIRE_JB15_ALU54,
    TILE_WIRE_JB16_ALU54,
    TILE_WIRE_JB17_ALU54,
    TILE_WIRE_JB18_ALU54,
    TILE_WIRE_JB19_ALU54,
    TILE_WIRE_JB20_ALU54,
    TILE_WIRE_JB21_ALU54,
    TILE_WIRE_JB22_ALU54,
    TILE_WIRE_JB23_ALU54,
    TILE_WIRE_JB24_ALU54,
    TILE_WIRE_JB25_ALU54,
    TILE_WIRE_JB26_ALU54,
    TILE_WIRE_JB27_ALU54,
    TILE_WIRE_JB28_ALU54,
    TILE_WIRE_JB29_ALU54,
    TILE_WIRE_JB30_ALU54,
    TILE_WIRE_JB31_ALU54,
    TILE_WIRE_JB32_ALU54,
    TILE_WIRE_JB33_ALU54,
    TILE_WIRE_JB34_ALU54,
    TILE_WIRE_JB35_ALU54,
    TILE_WIRE_JMA0_ALU54,
    TILE_WIRE_JMA1_ALU54,
    TILE_WIRE_JMA2_ALU54,
    TILE_WIRE_JMA3_ALU54,
    TILE_WIRE_JMA4_ALU54,
    TILE_WIRE_JMA5_ALU54,
    TILE_WIRE_JMA6_ALU54,
    TILE_WIRE_JMA7_ALU54,
    TILE_WIRE_JMA8_ALU54,
    TILE_WIRE_JMA9_ALU54,
    TILE_WIRE_JMA10_ALU54,
    TILE_WIRE_JMA11_ALU54,
    TILE_WIRE_JMA12_ALU54,
    TILE_WIRE_JMA13_ALU54,
    TILE_WIRE_JMA14_ALU54,
    TILE_WIRE_JMA15_ALU54,
    TILE_WIRE_JMA16_ALU54,
    TILE_WIRE_JMA17_ALU54,
    TILE_WIRE_JMA18_ALU54,
    TILE_WIRE_JMA19_ALU54,
    TILE_WIRE_JMA20_ALU54,
    TILE_WIRE_JMA21_ALU54,
    TILE_WIRE_JMA22_ALU54,
    TILE_WIRE_JMA23_ALU54,
    TILE_WIRE_JMA24_ALU54,
    TILE_WIRE_JMA25_ALU54,
    TILE_WIRE_JMA26_ALU54,
    TILE_WIRE_JMA27_ALU54,
    TILE_WIRE_JMA28_ALU54,
    TILE_WIRE_JMA29_ALU54,
    TILE_WIRE_JMA30_ALU54,
    TILE_WIRE_JMA31_ALU54,
    TILE_WIRE_JMA32_ALU54,
    TILE_WIRE_JMA33_ALU54,
    TILE_WIRE_JMA34_ALU54,
    TILE_WIRE_JMA35_ALU54,
    TILE_WIRE_JMB0_ALU54,
    TILE_WIRE_JMB1_ALU54,
    TILE_WIRE_JMB2_ALU54,
    TILE_WIRE_JMB3_ALU54,
    TILE_WIRE_JMB4_ALU54,
    TILE_WIRE_JMB5_ALU54,
    TILE_WIRE_JMB6_ALU54,
    TILE_WIRE_JMB7_ALU54,
    TILE_WIRE_JMB8_ALU54,
    TILE_WIRE_JMB9_ALU54,
    TILE_WIRE_JMB10_ALU54,
    TILE_WIRE_JMB11_ALU54,
    TILE_WIRE_JMB12_ALU54,
    TILE_WIRE_JMB13_ALU54,
    TILE_WIRE_JMB14_ALU54,
    TILE_WIRE_JMB15_ALU54,
    TILE_WIRE_JMB16_ALU54,
    TILE_WIRE_JMB17_ALU54,
    TILE_WIRE_JMB18_ALU54,
    TILE_WIRE_JMB19_ALU54,
    TILE_WIRE_JMB20_ALU54,
    TILE_WIRE_JMB21_ALU54,
    TILE_WIRE_JMB22_ALU54,
    TILE_WIRE_JMB23_ALU54,
    TILE_WIRE_JMB24_ALU54,
    TILE_WIRE_JMB25_ALU54,
    TILE_WIRE_JMB26_ALU54,
    TILE_WIRE_JMB27_ALU54,
    TILE_WIRE_JMB28_ALU54,
    TILE_WIRE_JMB29_ALU54,
    TILE_WIRE_JMB30_ALU54,
    TILE_WIRE_JMB31_ALU54,
    TILE_WIRE_JMB32_ALU54,
    TILE_WIRE_JMB33_ALU54,
    TILE_WIRE_JMB34_ALU54,
    TILE_WIRE_JMB35_ALU54,
    TILE_WIRE_JC0_ALU54,
    TILE_WIRE_JC1_ALU54,
    TILE_WIRE_JC2_ALU54,
    TILE_WIRE_JC3_ALU54,
    TILE_WIRE_JC4_ALU54,
    TILE_WIRE_JC5_ALU54,
    TILE_WIRE_JC6_ALU54,
    TILE_WIRE_JC7_ALU54,
    TILE_WIRE_JC8_ALU54,
    TILE_WIRE_JC9_ALU54,
    TILE_WIRE_JC10_ALU54,
    TILE_WIRE_JC11_ALU54,
    TILE_WIRE_JC12_ALU54,
    TILE_WIRE_JC13_ALU54,
    TILE_WIRE_JC14_ALU54,
    TILE_WIRE_JC15_ALU54,
    TILE_WIRE_JC16_ALU54,
    TILE_WIRE_JC17_ALU54,
    TILE_WIRE_JC18_ALU54,
    TILE_WIRE_JC19_ALU54,
    TILE_WIRE_JC20_ALU54,
    TILE_WIRE_JC21_ALU54,
    TILE_WIRE_JC22_ALU54,
    TILE_WIRE_JC23_ALU54,
    TILE_WIRE_JC24_ALU54,
    TILE_WIRE_JC25_ALU54,
    TILE_WIRE_JC26_ALU54,
    TILE_WIRE_JC27_ALU54,
    TILE_WIRE_JC28_ALU54,
    TILE_WIRE_JC29_ALU54,
    TILE_WIRE_JC30_ALU54,
    TILE_WIRE_JC31_ALU54,
    TILE_WIRE_JC32_ALU54,
    TILE_WIRE_JC33_ALU54,
    TILE_WIRE_JC34_ALU54,
    TILE_WIRE_JC35_ALU54,
    TILE_WIRE_JC36_ALU54,
    TILE_WIRE_JC37_ALU54,
    TILE_WIRE_JC38_ALU54,
    TILE_WIRE_JC39_ALU54,
    TILE_WIRE_JC40_ALU54,
    TILE_WIRE_JC41_ALU54,
    TILE_WIRE_JC42_ALU54,
    TILE_WIRE_JC43_ALU54,
    TILE_WIRE_JC44_ALU54,
    TILE_WIRE_JC45_ALU54,
    TILE_WIRE_JC46_ALU54,
    TILE_WIRE_JC47_ALU54,
    TILE_WIRE_JC48_ALU54,
    TILE_WIRE_JC49_ALU54,
    TILE_WIRE_JC50_ALU54,
    TILE_WIRE_JC51_ALU54,
    TILE_WIRE_JC52_ALU54,
    TILE_WIRE_JC53_ALU54,
    TILE_WIRE_JCFB0_ALU54,
    TILE_WIRE_JCFB1_ALU54,
    TILE_WIRE_JCFB2_ALU54,
    TILE_WIRE_JCFB3_ALU54,
    TILE_WIRE_JCFB4_ALU54,
    TILE_WIRE_JCFB5_ALU54,
    TILE_WIRE_JCFB6_ALU54,
    TILE_WIRE_JCFB7_ALU54,
    TILE_WIRE_JCFB8_ALU54,
    TILE_WIRE_JCFB9_ALU54,
    TILE_WIRE_JCFB10_ALU54,
    TILE_WIRE_JCFB11_ALU54,
    TILE_WIRE_JCFB12_ALU54,
    TILE_WIRE_JCFB13_ALU54,
    TILE_WIRE_JCFB14_ALU54,
    TILE_WIRE_JCFB15_ALU54,
    TILE_WIRE_JCFB16_ALU54,
    TILE_WIRE_JCFB17_ALU54,
    TILE_WIRE_JCFB18_ALU54,
    TILE_WIRE_JCFB19_ALU54,
    TILE_WIRE_JCFB20_ALU54,
    TILE_WIRE_JCFB21_ALU54,
    TILE_WIRE_JCFB22_ALU54,
    TILE_WIRE_JCFB23_ALU54,
    TILE_WIRE_JCFB24_ALU54,
    TILE_WIRE_JCFB25_ALU54,
    TILE_WIRE_JCFB26_ALU54,
    TILE_WIRE_JCFB27_ALU54,
    TILE_WIRE_JCFB28_ALU54,
    TILE_WIRE_JCFB29_ALU54,
    TILE_WIRE_JCFB30_ALU54,
    TILE_WIRE_JCFB31_ALU54,
    TILE_WIRE_JCFB32_ALU54,
    TILE_WIRE_JCFB33_ALU54,
    TILE_WIRE_JCFB34_ALU54,
    TILE_WIRE_JCFB35_ALU54,
    TILE_WIRE_JCFB36_ALU54,
    TILE_WIRE_JCFB37_ALU54,
    TILE_WIRE_JCFB38_ALU54,
    TILE_WIRE_JCFB39_ALU54,
    TILE_WIRE_JCFB40_ALU54,
    TILE_WIRE_JCFB41_ALU54,
    TILE_WIRE_JCFB42_ALU54,
    TILE_WIRE_JCFB43_ALU54,
    TILE_WIRE_JCFB44_ALU54,
    TILE_WIRE_JCFB45_ALU54,
    TILE_WIRE_JCFB46_ALU54,
    TILE_WIRE_JCFB47_ALU54,
    TILE_WIRE_JCFB48_ALU54,
    TILE_WIRE_JCFB49_ALU54,
    TILE_WIRE_JCFB50_ALU54,
    TILE_WIRE_JCFB51_ALU54,
    TILE_WIRE_JCFB52_ALU54,
    TILE_WIRE_JCFB53_ALU54,
    TILE_WIRE_JCIN0_ALU54,
    TILE_WIRE_JCIN1_ALU54,
    TILE_WIRE_JCIN2_ALU54,
    TILE_WIRE_JCIN3_ALU54,
    TILE_WIRE_JCIN4_ALU54,
    TILE_WIRE_JCIN5_ALU54,
    TILE_WIRE_JCIN6_ALU54,
    TILE_WIRE_JCIN7_ALU54,
    TILE_WIRE_JCIN8_ALU54,
    TILE_WIRE_JCIN9_ALU54,
    TILE_WIRE_JCIN10_ALU54,
    TILE_WIRE_JCIN11_ALU54,
    TILE_WIRE_JCIN12_ALU54,
    TILE_WIRE_JCIN13_ALU54,
    TILE_WIRE_JCIN14_ALU54,
    TILE_WIRE_JCIN15_ALU54,
    TILE_WIRE_JCIN16_ALU54,
    TILE_WIRE_JCIN17_ALU54,
    TILE_WIRE_JCIN18_ALU54,
    TILE_WIRE_JCIN19_ALU54,
    TILE_WIRE_JCIN20_ALU54,
    TILE_WIRE_JCIN21_ALU54,
    TILE_WIRE_JCIN22_ALU54,
    TILE_WIRE_JCIN23_ALU54,
    TILE_WIRE_JCIN24_ALU54,
    TILE_WIRE_JCIN25_ALU54,
    TILE_WIRE_JCIN26_ALU54,
    TILE_WIRE_JCIN27_ALU54,
    TILE_WIRE_JCIN28_ALU54,
    TILE_WIRE_JCIN29_ALU54,
    TILE_WIRE_JCIN30_ALU54,
    TILE_WIRE_JCIN31_ALU54,
    TILE_WIRE_JCIN32_ALU54,
    TILE_WIRE_JCIN33_ALU54,
    TILE_WIRE_JCIN34_ALU54,
    TILE_WIRE_JCIN35_ALU54,
    TILE_WIRE_JCIN36_ALU54,
    TILE_WIRE_JCIN37_ALU54,
    TILE_WIRE_JCIN38_ALU54,
    TILE_WIRE_JCIN39_ALU54,
    TILE_WIRE_JCIN40_ALU54,
    TILE_WIRE_JCIN41_ALU54,
    TILE_WIRE_JCIN42_ALU54,
    TILE_WIRE_JCIN43_ALU54,
    TILE_WIRE_JCIN44_ALU54,
    TILE_WIRE_JCIN45_ALU54,
    TILE_WIRE_JCIN46_ALU54,
    TILE_WIRE_JCIN47_ALU54,
    TILE_WIRE_JCIN48_ALU54,
    TILE_WIRE_JCIN49_ALU54,
    TILE_WIRE_JCIN50_ALU54,
    TILE_WIRE_JCIN51_ALU54,
    TILE_WIRE_JCIN52_ALU54,
    TILE_WIRE_JCIN53_ALU54,
    TILE_WIRE_JOP0_ALU54,
    TILE_WIRE_JOP1_ALU54,
    TILE_WIRE_JOP2_ALU54,
    TILE_WIRE_JOP3_ALU54,
    TILE_WIRE_JOP4_ALU54,
    TILE_WIRE_JOP5_ALU54,
    TILE_WIRE_JOP6_ALU54,
    TILE_WIRE_JOP7_ALU54,
    TILE_WIRE_JOP8_ALU54,
    TILE_WIRE_JOP9_ALU54,
    TILE_WIRE_JOP10_ALU54,
    TILE_WIRE_JR0_ALU54,
    TILE_WIRE_JR1_ALU54,
    TILE_WIRE_JR2_ALU54,
    TILE_WIRE_JR3_ALU54,
    TILE_WIRE_JR4_ALU54,
    TILE_WIRE_JR5_ALU54,
    TILE_WIRE_JR6_ALU54,
    TILE_WIRE_JR7_ALU54,
    TILE_WIRE_JR8_ALU54,
    TILE_WIRE_JR9_ALU54,
    TILE_WIRE_JR10_ALU54,
    TILE_WIRE_JR11_ALU54,
    TILE_WIRE_JR12_ALU54,
    TILE_WIRE_JR13_ALU54,
    TILE_WIRE_JR14_ALU54,
    TILE_WIRE_JR15_ALU54,
    TILE_WIRE_JR16_ALU54,
    TILE_WIRE_JR17_ALU54,
    TILE_WIRE_JR18_ALU54,
    TILE_WIRE_JR19_ALU54,
    TILE_WIRE_JR20_ALU54,
    TILE_WIRE_JR21_ALU54,
    TILE_WIRE_JR22_ALU54,
    TILE_WIRE_JR23_ALU54,
    TILE_WIRE_JR24_ALU54,
    TILE_WIRE_JR25_ALU54,
    TILE_WIRE_JR26_ALU54,
    TILE_WIRE_JR27_ALU54,
    TILE_WIRE_JR28_ALU54,
    TILE_WIRE_JR29_ALU54,
    TILE_WIRE_JR30_ALU54,
    TILE_WIRE_JR31_ALU54,
    TILE_WIRE_JR32_ALU54,
    TILE_WIRE_JR33_ALU54,
    TILE_WIRE_JR34_ALU54,
    TILE_WIRE_JR35_ALU54,
    TILE_WIRE_JR36_ALU54,
    TILE_WIRE_JR37_ALU54,
    TILE_WIRE_JR38_ALU54,
    TILE_WIRE_JR39_ALU54,
    TILE_WIRE_JR40_ALU54,
    TILE_WIRE_JR41_ALU54,
    TILE_WIRE_JR42_ALU54,
    TILE_WIRE_JR43_ALU54,
    TILE_WIRE_JR44_ALU54,
    TILE_WIRE_JR45_ALU54,
    TILE_WIRE_JR46_ALU54,
    TILE_WIRE_JR47_ALU54,
    TILE_WIRE_JR48_ALU54,
    TILE_WIRE_JR49_ALU54,
    TILE_WIRE_JR50_ALU54,
    TILE_WIRE_JR51_ALU54,
    TILE_WIRE_JR52_ALU54,
    TILE_WIRE_JR53_ALU54,
    TILE_WIRE_JCO0_ALU54,
    TILE_WIRE_JCO1_ALU54,
    TILE_WIRE_JCO2_ALU54,
    TILE_WIRE_JCO3_ALU54,
    TILE_WIRE_JCO4_ALU54,
    TILE_WIRE_JCO5_ALU54,
    TILE_WIRE_JCO6_ALU54,
    TILE_WIRE_JCO7_ALU54,
    TILE_WIRE_JCO8_ALU54,
    TILE_WIRE_JCO9_ALU54,
    TILE_WIRE_JCO10_ALU54,
    TILE_WIRE_JCO11_ALU54,
    TILE_WIRE_JCO12_ALU54,
    TILE_WIRE_JCO13_ALU54,
    TILE_WIRE_JCO14_ALU54,
    TILE_WIRE_JCO15_ALU54,
    TILE_WIRE_JCO16_ALU54,
    TILE_WIRE_JCO17_ALU54,
    TILE_WIRE_JCO18_ALU54,
    TILE_WIRE_JCO19_ALU54,
    TILE_WIRE_JCO20_ALU54,
    TILE_WIRE_JCO21_ALU54,
    TILE_WIRE_JCO22_ALU54,
    TILE_WIRE_JCO23_ALU54,
    TILE_WIRE_JCO24_ALU54,
    TILE_WIRE_JCO25_ALU54,
    TILE_WIRE_JCO26_ALU54,
    TILE_WIRE_JCO27_ALU54,
    TILE_WIRE_JCO28_ALU54,
    TILE_WIRE_JCO29_ALU54,
    TILE_WIRE_JCO30_ALU54,
    TILE_WIRE_JCO31_ALU54,
    TILE_WIRE_JCO32_ALU54,
    TILE_WIRE_JCO33_ALU54,
    TILE_WIRE_JCO34_ALU54,
    TILE_WIRE_JCO35_ALU54,
    TILE_WIRE_JCO36_ALU54,
    TILE_WIRE_JCO37_ALU54,
    TILE_WIRE_JCO38_ALU54,
    TILE_WIRE_JCO39_ALU54,
    TILE_WIRE_JCO40_ALU54,
    TILE_WIRE_JCO41_ALU54,
    TILE_WIRE_JCO42_ALU54,
    TILE_WIRE_JCO43_ALU54,
    TILE_WIRE_JCO44_ALU54,
    TILE_WIRE_JCO45_ALU54,
    TILE_WIRE_JCO46_ALU54,
    TILE_WIRE_JCO47_ALU54,
    TILE_WIRE_JCO48_ALU54,
    TILE_WIRE_JCO49_ALU54,
    TILE_WIRE_JCO50_ALU54,
    TILE_WIRE_JCO51_ALU54,
    TILE_WIRE_JCO52_ALU54,
    TILE_WIRE_JCO53_ALU54,
    TILE_WIRE_JEQZ_ALU54,
    TILE_WIRE_JEQZM_ALU54,
    TILE_WIRE_JEQOM_ALU54,
    TILE_WIRE_JEQPAT_ALU54,
    TILE_WIRE_JEQPATB_ALU54,
    TILE_WIRE_JOVER_ALU54,
    TILE_WIRE_JUNDER_ALU54,
    TILE_WIRE_JOVERUNDER_ALU54,
    TILE_WIRE_JSIGNEDR_ALU54,

    TILE_WIRE_JCE0,
    TILE_WIRE_JCE1,
    TILE_WIRE_JCE2,
    TILE_WIRE_JCE3,
    TILE_WIRE_JCLK0,
    TILE_WIRE_JCLK1,
    TILE_WIRE_JLSR0,
    TILE_WIRE_JLSR1,

    TILE_WIRE_JA0,
    TILE_WIRE_JA1,
    TILE_WIRE_JA2,
    TILE_WIRE_JA3,
    TILE_WIRE_JA4,
    TILE_WIRE_JA5,
    TILE_WIRE_JA6,
    TILE_WIRE_JA7,
    TILE_WIRE_JB0,
    TILE_WIRE_JB1,
    TILE_WIRE_JB2,
    TILE_WIRE_JB3,
    TILE_WIRE_JB4,
    TILE_WIRE_JB5,
    TILE_WIRE_JB6,
    TILE_WIRE_JB7,
    TILE_WIRE_JC0,
    TILE_WIRE_JC1,
    TILE_WIRE_JC2,
    TILE_WIRE_JC3,
    TILE_WIRE_JC4,
    TILE_WIRE_JC5,
    TILE_WIRE_JC6,
    TILE_WIRE_JC7,
    TILE_WIRE_JD0,
    TILE_WIRE_JD1,
    TILE_WIRE_JD2,
    TILE_WIRE_JD3,
    TILE_WIRE_JD4,
    TILE_WIRE_JD5,
    TILE_WIRE_JD6,
    TILE_WIRE_JD7,
    TILE_WIRE_JM0,
    TILE_WIRE_JM1,
    TILE_WIRE_JM2,
    TILE_WIRE_JM3,
    TILE_WIRE_JM4,
    TILE_WIRE_JM5,
    TILE_WIRE_JM6,
    TILE_WIRE_JM7,
    TILE_WIRE_JF0,
    TILE_WIRE_JF1,
    TILE_WIRE_JF2,
    TILE_WIRE_JF3,
    TILE_WIRE_JF4,
    TILE_WIRE_JF5,
    TILE_WIRE_JF6,
    TILE_WIRE_JF7,
    TILE_WIRE_JQ0,
    TILE_WIRE_JQ1,
    TILE_WIRE_JQ2,
    TILE_WIRE_JQ3,
    TILE_WIRE_JQ4,
    TILE_WIRE_JQ5,
    TILE_WIRE_JQ6,
    TILE_WIRE_JQ7

};

void gfxTileWire(std::vector<GraphicElement> &g, int x, int y, int w, int h, IdString wire_type, GfxTileWireId tilewire,
                 GraphicElement::style_t style);
void gfxTilePip(std::vector<GraphicElement> &g, int x, int y, int w, int h, WireId src, IdString src_type,
                GfxTileWireId src_id, WireId dst, IdString dst_type, GfxTileWireId dst_id,
                GraphicElement::style_t style);

NEXTPNR_NAMESPACE_END

#endif
